@@ -13,10 +13,10 @@ class MetaActuator(type):
   classes = {}
   needed_methods = ["open", "stop", ('set_speed', 'set_position'), 'close']
 
-  def __new__(mcs, name, bases, dict_):
+  def __new__(mcs, name: str, bases: tuple, dict_: dict) -> type:
     return type.__new__(mcs, name, bases, dict_)
 
-  def __init__(cls, name, bases, dict_):
+  def __init__(cls, name: str, bases: tuple, dict_: dict) -> None:
     type.__init__(cls, name, bases, dict_)  # This is the important line
     if name in MetaActuator.classes:
       raise DefinitionError("Cannot redefine " + name + " class")
@@ -40,5 +40,5 @@ class MetaActuator(type):
     MetaActuator.classes[name] = cls
 
 
-class Actuator(object, metaclass=MetaActuator):
+class Actuator(metaclass=MetaActuator):
   pass
