@@ -17,14 +17,15 @@ class Grapher(Block):
   """The grapher receive data from a block (via a :ref:`Link`) and plots it."""
 
   def __init__(self,
-               *labels,
-               length=0,
-               freq=2,
-               maxpt=20000,
-               window_size=(8, 8),
-               window_pos=None,
-               interp=True,
-               backend="TkAgg"):
+               *labels: tuple,
+               length: int = 0,
+               freq: float = 2,
+               maxpt: int = 20000,
+               window_size: tuple = (8, 8),
+               window_pos: tuple = None,
+               interp: bool = True,
+               backend: str = "TkAgg",
+               verbose: bool = False) -> None:
     """Sets the args and initializes the parent class.
 
     Args:
@@ -49,6 +50,8 @@ class Grapher(Block):
         be linked to the following by straight lines. Else, each value wil be
         displayed as constant until the next update.
       backend (:obj:`int`, optional): The :mod:`matplotlib` backend to use.
+      verbose (:obj:`bool`, optional): To display the loop frequency of the
+        block.
 
     Example:
       ::
@@ -77,10 +80,11 @@ class Grapher(Block):
     self.window_pos = window_pos
     self.interp = interp
     self.backend = backend
+    self.verbose = verbose
 
     self.labels = labels
 
-  def prepare(self):
+  def prepare(self) -> None:
     if self.backend:
       plt.switch_backend(self.backend)
     self.f = plt.figure(figsize=self.window_size)
@@ -111,14 +115,14 @@ class Grapher(Block):
     plt.draw()
     plt.pause(.001)
 
-  def clear(self, *_, **__):
+  def clear(self, *_, **__) -> None:
     for line in self.lines:
       line.set_xdata([])
       line.set_ydata([])
     self.factor = [1 for _ in self.labels]
     self.counter = [0 for _ in self.labels]
 
-  def loop(self):
+  def loop(self) -> None:
     # We need to recv data from all the links, but keep
     # ALL of the data, even with the same label (so not get_all_last)
     data = self.recv_all_delay()
@@ -152,5 +156,5 @@ class Grapher(Block):
     self.f.canvas.draw()  # Update the graph
     self.f.canvas.flush_events()
 
-  def finish(self):
+  def finish(self) -> None:
     plt.close("all")
